<?php

/**
 * @file
 *
 * Defines the mapping from telephone number country codes (as defined by
 *   ITU-T recommendation E.164, transcribed from
 *   http://www.itu.int/publ/T-SP-E.164D-2007/en (version 2007) on 28 Nov
 *   2008) to ISO 3166-1-alpha-2 codes (a two-letter code representing
 *   countries of the world; transcribed from
 *   http://www.iso.org/iso/iso-3166-1_decoding_table on 28 Nov 2008; see also
 *   http://en.wikipedia.org/wiki/ISO_3166-1_alpha-2).
 *
 */

/**
 * Return a map from telephone country codes to ISO 3166-1-alpha-2 country codes.
 *
 * @return
 *   An array with telephone country codes as keys and ISO 3166-1-alpha-2
 *   country codes as values.
 */
function _world_phone_country_to_country_code_map() {
  return array (
// Canadian phone numbers cannot be distinguished by country code
    'CA' => '1',
    'US' => '1',
    'BS' => '1242',
    'BB' => '1246',
    'AI' => '1264',
    'AG' => '1268',
    'VG' => '1284',
    'VI' => '1340',
    'KY' => '1345',
    'BM' => '1441',
    'GD' => '1473',
    'TC' => '1649',
    'MS' => '1664',
    'MP' => '1670',
    'GU' => '1671',
    'AS' => '1684',
    'LC' => '1758',
    'DM' => '1767',
    'VC' => '1784',
    'PR' => '1787',
    'DO' => '1809',
    'DO' => '1829',
    'TT' => '1868',
    'KN' => '1869',
    'JM' => '1876',
    'PR' => '1939',
    'EG' => '20',
    'MA' => '212',
    'DZ' => '213',
    'TN' => '216',
    'LY' => '218',
    'GM' => '220',
    'SN' => '221',
    'MR' => '222',
    'ML' => '223',
    'GN' => '224',
    'CI' => '225',
    'BF' => '226',
    'NE' => '227',
    'TG' => '228',
    'BJ' => '229',
    'MU' => '230',
    'LR' => '231',
    'SL' => '232',
    'GH' => '233',
    'NG' => '234',
    'TD' => '235',
    'CF' => '236',
    'CM' => '237',
    'CV' => '238',
    'ST' => '239',
    'GQ' => '240',
    'GA' => '241',
    'CG' => '242',
    'CD' => '243',
    'AO' => '244',
    'GW' => '245',
    'IO' => '246',
    'AC' => '247',
    'SC' => '248',
    'SD' => '249',
    'RW' => '250',
    'ET' => '251',
    'SO' => '252',
    'DJ' => '253',
    'KE' => '254',
    'TZ' => '255',
    'UG' => '256',
    'BI' => '257',
    'MZ' => '258',
    'ZM' => '260',
    'MG' => '261',
    'RE' => '262',
    'ZW' => '263',
    'NA' => '264',
    'MW' => '265',
    'LS' => '266',
    'BW' => '267',
    'SZ' => '268',
    'KM' => '269',
    'ZA' => '27',
    'SH' => '290',
    'ER' => '291',
    'AW' => '297',
    'FO' => '298',
    'GL' => '299',
    'GR' => '30',
    'NL' => '31',
    'BE' => '32',
    'FR' => '33',
    'ES' => '34',
    'GI' => '350',
    'PT' => '351',
    'LU' => '352',
    'IE' => '353',
    'IS' => '354',
    'AL' => '355',
    'MT' => '356',
    'CY' => '357',
    'FI' => '358',
    'BG' => '359',
    'HU' => '36',
    'LT' => '370',
    'LV' => '371',
    'EE' => '372',
    'MD' => '373',
    'AM' => '374',
    'BY' => '375',
    'AD' => '376',
    'MC' => '377',
    'SM' => '378',
    'VA' => '379',
    'UA' => '380',
    'RS' => '381',
    'ME' => '382',
    'HR' => '385',
    'SI' => '386',
    'BA' => '387',
    'EU' => '388',
    'MK' => '389',
    'IT' => '39',
    'RO' => '40',
    'CH' => '41',
    'CZ' => '420',
    'SK' => '421',
    'LI' => '423',
    'AT' => '43',
    'GB' => '44',
    'DK' => '45',
    'SE' => '46',
    'NO' => '47',
    'PL' => '48',
    'DE' => '49',
    'FK' => '500',
    'BZ' => '501',
    'GT' => '502',
    'SV' => '503',
    'HN' => '504',
    'NI' => '505',
    'CR' => '506',
    'PA' => '507',
    'PM' => '508',
    'HT' => '509',
    'PE' => '51',
    'MX' => '52',
    'CU' => '53',
    'AR' => '54',
    'BR' => '55',
    'CL' => '56',
    'CO' => '57',
    'VE' => '58',
    'GP' => '590',
    'BO' => '591',
    'GY' => '592',
    'EC' => '593',
    'GF' => '594',
    'PY' => '595',
    'MQ' => '596',
    'SR' => '597',
    'UY' => '598',
    'AN' => '599',
    'MY' => '60',
    'AU' => '61',
    'ID' => '62',
    'PH' => '63',
    'NZ' => '64',
    'SG' => '65',
    'TH' => '66',
    'TL' => '670',
    'NF' => '672',
    'BN' => '673',
    'NR' => '674',
    'PG' => '675',
    'TO' => '676',
    'SB' => '677',
    'VU' => '678',
    'FJ' => '679',
    'PW' => '680',
    'WF' => '681',
    'CK' => '682',
    'NU' => '683',
    'WS' => '685',
    'KI' => '686',
    'NC' => '687',
    'TV' => '688',
    'PF' => '689',
    'TK' => '690',
    'FM' => '691',
    'MH' => '692',
    'RU' => '7',
    'KZ' => '76',
    'KZ' => '77',
//      'XT' => '800',
    'XS' => '808',
//      'XS' => '808',
    'JP' => '81',
    'KR' => '82',
    'VN' => '84',
    'KP' => '850',
    'HK' => '852',
    'MO' => '853',
    'KH' => '855',
    'LA' => '856',
    'CN' => '86',
//      'XN' => '870',
//      'XE' => '871',
//      'XF' => '872',
//      'XI' => '873',
//      'XW' => '874',
//      'XP' => '878',
    'BD' => '880',
//      'XG' => '881',
//      'XV' => '882',
    'TW' => '886',
    'TR' => '90',
    'IN' => '91',
    'PK' => '92',
    'AF' => '93',
    'LK' => '94',
    'MM' => '95',
    'MV' => '960',
    'LB' => '961',
    'JO' => '962',
    'SY' => '963',
    'IQ' => '964',
    'KW' => '965',
    'SA' => '966',
    'YE' => '967',
    'OM' => '968',
    'PS' => '970',
    'AE' => '971',
    'IL' => '972',
    'BH' => '973',
    'QA' => '974',
    'BT' => '975',
    'MN' => '976',
    'NP' => '977',
    'IR' => '98',
    'TJ' => '992',
    'TM' => '993',
    'AZ' => '994',
    'GE' => '995',
    'KG' => '996',
    'UZ' => '998',
  );
}
