<?php

/**
 * @file
 *
 * Defines the mapping from ISO 3166-1-alpha-2 codes (a two-letter code
 *   representing countries of the world; transcribed from
 *   http://www.iso.org/iso/iso-3166-1_decoding_table on 28 Nov 2008; see also
 *   http://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) to English short country names
 *   officially used by the ISO 3166 Maintenance Agency (ISO 3166/MA).
 *
 */

/**
 * Return a map from ISO 3166-1-alpha-2 country codes to ISO 3166 short
 * country names (in English, but with optional translation via Locale
 * module).
 *
 * Note that, to prevent PHP errors with the character set, the original
 * characters in "Cote D'Ivoire" and "Reunion" have been modified in this
 * file; hence, their spellings are incorrect.
 */
function _world_phone_country_to_shortname_map() {
  return array(
    'CA' => t('Canada'),
    'US' => t('United States'),
    'BS' => t('Bahamas'),
    'BB' => t('Barbados'),
    'AI' => t('Anguilla'),
    'AG' => t('Antigua and Barbuda'),
    'VG' => t('Virgin Islands, British'),
    'VI' => t('Virgin Islands, U.S.'),
    'KY' => t('Cayman Islands'),
    'BM' => t('Bermuda'),
    'GD' => t('Grenada'),
    'TC' => t('Turks and Caicos Islands'),
    'MS' => t('Montserrat'),
    'MP' => t('Northern Mariana Islands'),
    'GU' => t('Guam'),
    'AS' => t('American Samoa'),
    'LC' => t('Saint Lucia'),
    'DM' => t('Dominica'),
    'VC' => t('Saint Vincent and the Grenadines'),
    'PR' => t('Puerto Rico'),
    'DO' => t('Dominican Republic'),
    'TT' => t('Trinidad and Tobago'),
    'KN' => t('Saint Kitts and Nevis'),
    'JM' => t('Jamaica'),
    'PR' => t('Puerto Rico'),
    'EG' => t('Egypt'),
    'MA' => t('Morocco'),
    'DZ' => t('Algeria'),
    'TN' => t('Tunisia'),
    'LY' => t('Libyan Arab Jamahiriya'),
    'GM' => t('Gambia'),
    'SN' => t('Senegal'),
    'MR' => t('Mauritania'),
    'ML' => t('Mali'),
    'GN' => t('Guinea'),
    'CI' => t("Cote d'Ivoire"),
    'BF' => t('Burkina Faso'),
    'NE' => t('Niger'),
    'TG' => t('Togo'),
    'BJ' => t('Benin'),
    'MU' => t('Mauritius'),
    'LR' => t('Liberia'),
    'SL' => t('Sierra Leone'),
    'GH' => t('Ghana'),
    'NG' => t('Nigeria'),
    'TD' => t('Chad'),
    'CF' => t('Central African Republic'),
    'CM' => t('Cameroon'),
    'CV' => t('Cape Verde'),
    'ST' => t('Sao Tome and Principe'),
    'GQ' => t('Equatorial Guinea'),
    'GA' => t('Gabon'),
    'CG' => t('Congo'),
    'CD' => t('Congo, The Democratic Republic of the'),
    'AO' => t('Angola'),
    'GW' => t('Guinea-Bissau'),
    'IO' => t('British Indian Ocean Territory'),
    'AC' => t('Ascension Island'),
    'SC' => t('Seychelles'),
    'SD' => t('Sudan'),
    'RW' => t('Rwanda'),
    'ET' => t('Ethiopia'),
    'SO' => t('Somalia'),
    'DJ' => t('Djibouti'),
    'KE' => t('Kenya'),
    'TZ' => t('Tanzania, United Republic of'),
    'UG' => t('Uganda'),
    'BI' => t('Burundi'),
    'MZ' => t('Mozambique'),
    'ZM' => t('Zambia'),
    'MG' => t('Madagascar'),
    'RE' => t('Reunion'),
    'ZW' => t('Zimbabwe'),
    'NA' => t('Namibia'),
    'MW' => t('Malawi'),
    'LS' => t('Lesotho'),
    'BW' => t('Botswana'),
    'SZ' => t('Swaziland'),
    'KM' => t('Comoros'),
    'ZA' => t('South Africa'),
    'SH' => t('Saint Helena'),
    'ER' => t('Eritrea'),
    'AW' => t('Aruba'),
    'FO' => t('Faroe Islands'),
    'GL' => t('Greenland'),
    'GR' => t('Greece'),
    'NL' => t('Netherlands'),
    'BE' => t('Belgium'),
    'FR' => t('France'),
    'ES' => t('Spain'),
    'GI' => t('Gibraltar'),
    'PT' => t('Portugal'),
    'LU' => t('Luxembourg'),
    'IE' => t('Ireland'),
    'IS' => t('Iceland'),
    'AL' => t('Albania'),
    'MT' => t('Malta'),
    'CY' => t('Cyprus'),
    'FI' => t('Finland'),
    'BG' => t('Bulgaria'),
    'HU' => t('Hungary'),
    'LT' => t('Lithuania'),
    'LV' => t('Latvia'),
    'EE' => t('Estonia'),
    'MD' => t('Moldova'),
    'AM' => t('Armenia'),
    'BY' => t('Belarus'),
    'AD' => t('Andorra'),
    'MC' => t('Monaco'),
    'SM' => t('San Marino'),
    'VA' => t('Holy See (Vatican City State)'),
    'UA' => t('Ukraine'),
    'RS' => t('Serbia'),
    'ME' => t('Montenegro'),
    'HR' => t('Croatia'),
    'SI' => t('Slovenia'),
    'BA' => t('Bosnia and Herzegovina'),
    'EU' => t('European Union'),
    'MK' => t('Macedonia, The Former Yugoslav Republic of'),
    'IT' => t('Italy'),
    'RO' => t('Romania'),
    'CH' => t('Switzerland'),
    'CZ' => t('Czech Republic'),
    'SK' => t('Slovakia'),
    'LI' => t('Liechtenstein'),
    'AT' => t('Austria'),
    'GB' => t('United Kingdom'),
    'DK' => t('Denmark'),
    'SE' => t('Sweden'),
    'NO' => t('Norway'),
    'PL' => t('Poland'),
    'DE' => t('Germany'),
    'FK' => t('Falkland Islands (Malvinas)'),
    'BZ' => t('Belize'),
    'GT' => t('Guatemala'),
    'SV' => t('El Salvador'),
    'HN' => t('Honduras'),
    'NI' => t('Nicaragua'),
    'CR' => t('Costa Rica'),
    'PA' => t('Panama'),
    'PM' => t('Saint Pierre and Miquelon'),
    'HT' => t('Haiti'),
    'PE' => t('Peru'),
    'MX' => t('Mexico'),
    'CU' => t('Cuba'),
    'AR' => t('Argentina'),
    'BR' => t('Brazil'),
    'CL' => t('Chile'),
    'CO' => t('Colombia'),
    'VE' => t('Venezuela'),
    'GP' => t('Guadeloupe'),
    'BO' => t('Bolivia'),
    'GY' => t('Guyana'),
    'EC' => t('Ecuador'),
    'GF' => t('French Guiana'),
    'PY' => t('Paraguay'),
    'MQ' => t('Martinique'),
    'SR' => t('Suriname'),
    'UY' => t('Uruguay'),
    'AN' => t('Netherlands Antilles'),
    'MY' => t('Malaysia'),
    'AU' => t('Australia'),
    'ID' => t('Indonesia'),
    'PH' => t('Philippines'),
    'NZ' => t('New Zealand'),
    'SG' => t('Singapore'),
    'TH' => t('Thailand'),
    'TL' => t('Timor-Leste'),
    'NF' => t('Norfolk Island'),
    'BN' => t('Brunei Darussalam'),
    'NR' => t('Nauru'),
    'PG' => t('Papua New Guinea'),
    'TO' => t('Tonga'),
    'SB' => t('Solomon Islands'),
    'VU' => t('Vanuatu'),
    'FJ' => t('Fiji'),
    'PW' => t('Palau'),
    'WF' => t('Wallis and Futuna'),
    'CK' => t('Cook Islands'),
    'NU' => t('Niue'),
    'WS' => t('Samoa'),
    'KI' => t('Kiribati'),
    'NC' => t('New Caledonia'),
    'TV' => t('Tuvalu'),
    'PF' => t('French Polynesia'),
    'TK' => t('Tokelau'),
    'FM' => t('Micronesia, Federated States of'),
    'MH' => t('Marshall Islands'),
    'RU' => t('Russian Federation'),
    'KZ' => t('Kazakhstan'),
    'KZ' => t('Kazakhstan'),
//      'XT' => t('International Freephone Service'),
    'XS' => t('Wake Island'),
//      'XS' => t('International Shared Cost Service (ISCS)'),
    'JP' => t('Japan'),
    'KR' => t('Korea, Republic of'), //south
    'VN' => t('Viet Nam'),
    'KP' => t('Korea, Democratic People\'s Republic of'), //north
    'HK' => t('Hong Kong'),
    'MO' => t('Macao'),
    'KH' => t('Cambodia'),
    'LA' => t('Lao People\'s Democratic Republic'),
    'CN' => t('China'),
//      'XN' => t('Inmarsat SNAC'),
//      'XE' => t('Inmarsat (Atlantic Ocean - East)'),
//      'XF' => t('Inmarsat (Pacific Ocean)'),
//      'XI' => t('Inmarsat (Indian Ocean)'),
//      'XW' => t('Inmarsat (Atlantic Ocean - West)'),
//      'XP' => t('Universal Personal Telecommunications (UPT)'),
    'BD' => t('Bangladesh'),
//      'XG' => t('Global Mobile Satellite System (GMSS)'),
//      'XV' => t('EMSAT (Mobile Satellite service)'),
    'TW' => t('Taiwan, Province of China'),
    'TR' => t('Turkey'),
    'IN' => t('India'),
    'PK' => t('Pakistan'),
    'AF' => t('Afghanistan'),
    'LK' => t('Sri Lanka'),
    'MM' => t('Myanmar'),
    'MV' => t('Maldives'),
    'LB' => t('Lebanon'),
    'JO' => t('Jordan'),
    'SY' => t('Syrian Arab Republic'),
    'IQ' => t('Iraq'),
    'KW' => t('Kuwait'),
    'SA' => t('Saudi Arabia'),
    'YE' => t('Yemen'),
    'OM' => t('Oman'),
    'PS' => t('Palestinian Territory, Occupied'),
    'AE' => t('United Arab Emirates'),
    'IL' => t('Israel'),
    'BH' => t('Bahrain'),
    'QA' => t('Qatar'),
    'BT' => t('Bhutan'),
    'MN' => t('Mongolia'),
    'NP' => t('Nepal'),
    'IR' => t('Iran, Islamic Republic of'),
    'TJ' => t('Tajikistan'),
    'TM' => t('Turkmenistan'),
    'AZ' => t('Azerbaijan'),
    'GE' => t('Georgia'),
    'KG' => t('Kyrgyzstan'),
    'UZ' => t('Uzbekistan'),
  );
}